@@ -1,7 +1,7 @@
 package Calendar::Dates::CFA;
 
-our $DATE = '2019-02-15'; # DATE
-our $VERSION = '0.005'; # VERSION
+our $DATE = '2019-05-25'; # DATE
+our $VERSION = '0.006'; # VERSION
 
 use 5.010001;
 use strict;
@@ -25,7 +25,7 @@ Calendar::Dates::CFA - CFA exam calendar
 
 =head1 VERSION
 
-This document describes version 0.005 of Calendar::Dates::CFA (from Perl distribution Calendar-Dates-CFA), released on 2019-02-15.
+This document describes version 0.006 of Calendar::Dates::CFA (from Perl distribution Calendar-Dates-CFA), released on 2019-05-25.
 
 =head1 SYNOPSIS
 
@@ -33,7 +33,7 @@ This document describes version 0.005 of Calendar::Dates::CFA (from Perl distrib
 
  use Calendar::Dates::CFA;
  my $min_year = Calendar::Dates::CFA->get_min_year; # => 2018
- my $max_year = Calendar::Dates::CFA->get_max_year; # => 2019
+ my $max_year = Calendar::Dates::CFA->get_max_year; # => 2020
  my $entries  = Calendar::Dates::CFA->get_entries(2019);
 
 C<$entries> result:
@@ -151,6 +151,14 @@ C<$entries> result:
      tags    => ["dec2019exam"],
      year    => 2019,
    },
+   {
+     date    => "2019-12-03",
+     day     => 3,
+     month   => 12,
+     summary => "Test center change request submission deadline",
+     tags    => ["dec2019exam"],
+     year    => 2019,
+   },
    {
      date    => "2019-12-07",
      day     => 7,
@@ -159,6 +167,14 @@ C<$entries> result:
      tags    => ["dec2019exam"],
      year    => 2019,
    },
+   {
+     date    => "2019-12-08",
+     day     => 8,
+     month   => 12,
+     summary => "Religious alternate exam date",
+     tags    => ["dec2019exam"],
+     year    => 2019,
+   },
  ]
 
 =head2 Using from CLI (requires L<list-calendar-dates> and L<calx>)
@@ -176,41 +192,52 @@ This module provides CFA exam calendar using the L<Calendar::Dates> interface.
  | key           | value |
  +---------------+-------+
  | Earliest year | 2018  |
- | Latest year   | 2019  |
+ | Latest year   | 2020  |
  +---------------+-------+
 
 =head1 DATES SAMPLES
 
 Entries for year 2018:
 
- +------------+-----+-------+-----------------------------------------------------+-------------+------+
- | date       | day | month | summary                                             | tags        | year |
- +------------+-----+-------+-----------------------------------------------------+-------------+------+
- | 2018-10-15 | 15  | 10    | First deadline to request disability accommodations | jun2019exam | 2018 |
- | 2018-10-17 | 17  | 10    | Early registration fee deadline                     | jun2019exam | 2018 |
- +------------+-----+-------+-----------------------------------------------------+-------------+------+
+ +------------+-----------------------------------------------------+-------------+
+ | date       | summary                                             | tags        |
+ +------------+-----------------------------------------------------+-------------+
+ | 2018-10-15 | First deadline to request disability accommodations | jun2019exam |
+ | 2018-10-17 | Early registration fee deadline                     | jun2019exam |
+ +------------+-----------------------------------------------------+-------------+
 
 Entries for year 2019:
 
- +------------+-----+-------+--------------------------------------------------------------------------+-------------+------+
- | date       | day | month | summary                                                                  | tags        | year |
- +------------+-----+-------+--------------------------------------------------------------------------+-------------+------+
- | 2019-01-23 | 23  | 1     | Exam results announcement (Dec 2018, Levels I & II)                      | dec2018exam | 2019 |
- | 2019-02-13 | 13  | 2     | Standard registration fee deadline                                       | jun2019exam | 2019 |
- | 2019-02-18 | 18  | 2     | Second deadline to request disability accommodations                     | jun2019exam | 2019 |
- | 2019-03-13 | 13  | 3     | Final (late) registration fee deadline                                   | jun2019exam | 2019 |
- | 2019-03-18 | 18  | 3     | Final deadline to request disability accommodations                      | jun2019exam | 2019 |
- | 2019-06-11 | 11  | 6     | Deadline for submission of test center change requests                   | jun2019exam | 2019 |
- | 2019-06-15 | 15  | 6     | Exam day: Asia-Pacific (Levels II & III), Americas and EMEA (all levels) | jun2019exam | 2019 |
- | 2019-06-16 | 16  | 6     | Exam day: Asia-Pacific (Level I only)                                    | jun2019exam | 2019 |
- | 2019-06-16 | 16  | 6     | Religious alternate exam date (Americas and EMEA, all levels)            | jun2019exam | 2019 |
- | 2019-06-17 | 17  | 6     | Religious alternate exam date (Asia Pacific, all levels)                 | jun2019exam | 2019 |
- | 2019-01-24 | 24  | 1     | Exam registration open                                                   | dec2019exam | 2019 |
- | 2019-03-27 | 27  | 3     | Early registration fee deadline                                          | dec2019exam | 2019 |
- | 2019-08-14 | 14  | 8     | Standard registration fee deadline                                       | dec2019exam | 2019 |
- | 2019-09-11 | 11  | 9     | Final (late) registration fee deadline                                   | dec2019exam | 2019 |
- | 2019-12-07 | 7   | 12    | Exam day                                                                 | dec2019exam | 2019 |
- +------------+-----+-------+--------------------------------------------------------------------------+-------------+------+
+ +------------+--------------------------------------------------------------------------+-------------+
+ | date       | summary                                                                  | tags        |
+ +------------+--------------------------------------------------------------------------+-------------+
+ | 2019-01-23 | Exam results announcement (Dec 2018, Levels I & II)                      | dec2018exam |
+ | 2019-02-13 | Standard registration fee deadline                                       | jun2019exam |
+ | 2019-02-18 | Second deadline to request disability accommodations                     | jun2019exam |
+ | 2019-03-13 | Final (late) registration fee deadline                                   | jun2019exam |
+ | 2019-03-18 | Final deadline to request disability accommodations                      | jun2019exam |
+ | 2019-06-11 | Deadline for submission of test center change requests                   | jun2019exam |
+ | 2019-06-15 | Exam day: Asia-Pacific (Levels II & III), Americas and EMEA (all levels) | jun2019exam |
+ | 2019-06-16 | Exam day: Asia-Pacific (Level I only)                                    | jun2019exam |
+ | 2019-06-16 | Religious alternate exam date (Americas and EMEA, all levels)            | jun2019exam |
+ | 2019-06-17 | Religious alternate exam date (Asia Pacific, all levels)                 | jun2019exam |
+ | 2019-01-24 | Exam registration open                                                   | dec2019exam |
+ | 2019-03-27 | Early registration fee deadline                                          | dec2019exam |
+ | 2019-08-14 | Standard registration fee deadline                                       | dec2019exam |
+ | 2019-09-11 | Final (late) registration fee deadline                                   | dec2019exam |
+ | 2019-12-03 | Test center change request submission deadline                           | dec2019exam |
+ | 2019-12-07 | Exam day                                                                 | dec2019exam |
+ | 2019-12-08 | Religious alternate exam date                                            | dec2019exam |
+ +------------+--------------------------------------------------------------------------+-------------+
+
+Entries for year 2020:
+
+ +------------+--------------------------------------------------------------------------+-------------+
+ | date       | summary                                                                  | tags        |
+ +------------+--------------------------------------------------------------------------+-------------+
+ | 2020-06-06 | Exam day: Asia-Pacific (Levels II & III), Americas and EMEA (all levels) | jun2020exam |
+ | 2020-06-07 | Exam day: Asia-Pacific (Level I only)                                    | jun2020exam |
+ +------------+--------------------------------------------------------------------------+-------------+
 
 =head1 HOMEPAGE
 
@@ -277,4 +304,11 @@ __DATA__
 2019-03-27;Early registration fee deadline;dec2019exam
 2019-08-14;Standard registration fee deadline;dec2019exam
 2019-09-11;Final (late) registration fee deadline;dec2019exam
+2019-12-03;Test center change request submission deadline;dec2019exam
 2019-12-07;Exam day;dec2019exam
+2019-12-08;Religious alternate exam date;dec2019exam
+
+# jun2020exam
+# 2019-08-xx;Exam registration open;jun2020exam
+2020-06-06;Exam day: Asia-Pacific (Levels II & III), Americas and EMEA (all levels);jun2020exam
+2020-06-07;Exam day: Asia-Pacific (Level I only);jun2020exam
